@@ -47,7 +47,7 @@ def general_request(method: str, url: str, retries=3, **kwargs) -> str:
         read=retries,
         connect=retries,
         backoff_factor=0.3,
-        method_whitelist=False,
+        allowed_methods=None,
         raise_on_status=True,
     )
     adapter = HTTPAdapter(max_retries=retry)
@@ -56,7 +56,7 @@ def general_request(method: str, url: str, retries=3, **kwargs) -> str:
     try:
         r = session.request(method, url, proxies=proxies, **kwargs)
         r.raise_for_status()
-        logging.info("API called")
+        logging.info(f"Called {method} {url} {kwargs}")
         return r.text
     except ConnectionError as exc:
         error_type = str(exc)
